Learn R Programming

CFAssay (version 1.6.0)

cfa2way: Two-way analysis for cell survival data

Description

The function does an ANOVA of cell survival data from experimental 2-way designs where a treatment factor is tested on a control and on an altered cell line or where two different simultaneous treatments are tested on cells from a common unaltered clone. The function is a wrapper for the R-function glm. quasipoisson family is used with link function "log", i.e. dependency of treatment factors is considered as logarithmically additive.

Usage

cfa2way(X, A, B, param="A/B", method="ml")

Arguments

X
a data frame which contains columns Exp, ncells, ncolonies and two further columns for the treatment variables, see details.
A
a character string containing the name of a treatment or cell line variable (first factor in the model)
B
a character string containing the name of a treatment or cell line variable (second factor in the model)
param
Controls the parametrization of the model. Options are "A/B" for B nested in A , "B/A" for A nested in B and "A*B" for interaction term.
method
determines the method used for the fit. "ml" is for maximum-likelihood, "ls" for least-squares.

Value

The function returns an object of class cfa2way containing three elements, fit1, fit2 and anv. fit1 and fit2 are objects of class glm when method="ml" or of class lm when method="ls". fit1 has logarithmic additive parameters without interaction. fit2 has logarithmic additive parameters and interaction. anv is of class anova and contains the F-test. The full result is returned invisibly, i.e. the function has to be used with print or assigned to a variable, say for e.g. fitcomp as in the example below.

Details

In the data frame X, Exp identifies the experimental replicates and may be numeric or non-numeric. The two treatment or cell line columns should have numeric values 0, 1, ... for 2, 3, ... levels. For e.g. if a column describes clonal alteration (transfection, knock-down etc.) by a gene then 0 means unaltered or control and 1 means altered. Similar if a column describes treatment with one dose then 0 means untreated and 1 treated. 2 would indicate another dose level from the same treatment drug without taking it as a continuous covariate as for cell survival curves for radiation.

See Also

glm and family with references for generalized linear modelling.

Examples

Run this code
datatab<- read.table(system.file("doc", "exp2_2waycfa.txt", package="CFAssay"), header=TRUE, sep="\t")
names(datatab)  # has columns "x5fuCis" and "siRNA" 
fitcomp<- cfa2way(datatab, A="siRNA", B="x5fuCis", param="A/B")
print(fitcomp, labels=c(A="siRNA",B="x5fuCis"))
print(cfa2way(datatab, A="siRNA", B="x5fuCis", param="A/B", method="ls"))

Run the code above in your browser using DataLab