Learn R Programming

CFAssay (version 1.6.0)

pes: Calculation of plating efficiencies from a curve data set containing one specified curve

Description

The function calculates plating efficiencies, i.e. fractions of colonies per cell of untreated cells, for every experimental replicate in a data frame with one specified curve. For that, lines with zero dose ($dose = 0$) are extracted from the data frame.

Usage

pes(X)

Arguments

X
A data frame which contains columns Exp, dose, ncells, ncolonies.

Value

The function returns a data frame with three columns Exp, pe and S0, containing experiment identifiers (biological replicates), measured plating efficiencies and plating efficiencies fitted separately for each repeated experiments. Rows of the data frame are named for the different experiments.

Details

In the data frame X, Exp identifies the experimental replicates and may be numeric or non-numeric.

Examples

Run this code
datatab <- read.table(system.file("doc", "expl1_cellsurvcurves.txt", package="CFAssay"), header=TRUE, sep="\t")
X <- subset(datatab, cline=="okf6TERT1")  #Specification of curve
pes(X)
pes(subset(datatab, cline=="cal33") )

Run the code above in your browser using DataLab