Learn R Programming

CFAssay (version 1.6.0)

print.cellsurvLQfit: Print summary of an LQ-model fit for cell survival data

Description

The function prints the results of an LQ-model fit for radiation dose dependent cell survival.

Usage

"print"(x, ...)

Arguments

x
an object of class cellsurvLQfit resulting from cellsurvLQfit.
...
further arguments to pass to R function print.

Details

In this version of CFAssay the class argument x is checked by its entry fit$type and results in an error, when x results from an independent use of glm or lm.

See Also

cellsurvLQfit

Examples

Run this code
datatab<- read.table(system.file("doc", "expl1_cellsurvcurves.txt", package="CFAssay"), header=TRUE, sep="\t")
X<- subset(datatab, cline=="okf6TERT1")
fit<- cellsurvLQfit(X) #using default options
print(fit)
print(fit$type)
print(fit$PEmethod)
#using other options
print(cellsurvLQfit(X, method="ls"))
print(cellsurvLQfit(X, PEmethod="fix"))
print(cellsurvLQfit(X, method="ls", PEmethod="fix"))
print(cellsurvLQfit(X, method="franken"))

Run the code above in your browser using DataLab